## Changelog

### 0.0.3 (2020-10-03)
- Added four digits open the lock example
- Updated tests
- Updated readme
- Separated development guideline
- Added pylint and flake8

### 0.0.2 (2020-10-02)
- Release to PyPI

### 0.0.1 (2020-10-01)
- Initial release